package com.xunmei.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.xunmei.common.core.web.domain.AjaxResult;
import com.xunmei.common.core.web.page.TableDataInfo;
import com.xunmei.system.domain.SysWorkTimeSet;

import java.util.List;

/**
 * 作息设置Service接口
 *
 * @author xunmei
 * @date 2023-08-14
 */
public interface ISysWorkTimeSetService extends IService<SysWorkTimeSet> {
    /**
     * 查询作息设置
     *
     * @param id 作息设置主键
     * @return 作息设置
     */
    SysWorkTimeSet selectSysWorkTimeSetById(Long id);

    String add(SysWorkTimeSet request);

    /**
     * 查询作息设置列表
     *
     * @param sysWorkTimeSet 作息设置
     * @return 作息设置集合
     */
    List<SysWorkTimeSet> selectSysWorkTimeSetList(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 新增作息设置
     *
     * @param sysWorkTimeSet 作息设置
     * @return 结果
     */
    int insertSysWorkTimeSet(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 修改作息设置
     *
     * @param sysWorkTimeSet 作息设置
     * @return 结果
     */
    int updateSysWorkTimeSet(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 批量删除作息设置
     *
     * @param ids 需要删除的作息设置主键集合
     * @return 结果
     */
    int deleteSysWorkTimeSetByIds(Long[] ids);

    /**
     * 删除作息设置信息
     *
     * @param id 作息设置主键
     * @return 结果
     */
    int deleteSysWorkTimeSetById(Long id);

    /**
     * 查询作息设置分页数据
     *
     * @param sysWorkTimeSet 查询条件对象
     * @return Page
     */
    TableDataInfo selectPage(SysWorkTimeSet sysWorkTimeSet);

    AjaxResult workTimePageList(SysWorkTimeSet sysWorkTimeSet);
}
