package com.xunmei.system.mapper;

import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xunmei.system.domain.SysWorkTimeSet;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Param;

/**
 * 作息设置Mapper接口
 *
 * @author xunmei
 * @date 2023-08-14
 */
public interface SysWorkTimeSetMapper extends BaseMapper<SysWorkTimeSet> {
    /**
     * 查询作息设置
     *
     * @param id 作息设置主键
     * @return 作息设置
     */
     SysWorkTimeSet selectSysWorkTimeSetById(Long id);
    @MapKey("id")
     IPage<SysWorkTimeSet> selectByPage(Page<SysWorkTimeSet> page,SysWorkTimeSet sysWorkTimeSet );

    List<SysWorkTimeSet> findWorkTimeForOrgIdsAndErrectiveDate(@Param("orgIds") List<Long> orgIds, @Param("effectiveDate")Date effectiveDate);
    int checkData(@Param("request") SysWorkTimeSet request);
    List<SysWorkTimeSet> selectWorkTimeSetList(@Param("request") SysWorkTimeSet request);
    /**
     * 查询作息设置列表
     *
     * @param sysWorkTimeSet 作息设置
     * @return 作息设置集合
     */
     List<SysWorkTimeSet> selectSysWorkTimeSetList(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 新增作息设置
     *
     * @param sysWorkTimeSet 作息设置
     * @return 结果
     */
     int insertSysWorkTimeSet(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 修改作息设置
     *
     * @param sysWorkTimeSet 作息设置
     * @return 结果
     */
     int updateSysWorkTimeSet(SysWorkTimeSet sysWorkTimeSet);

    /**
     * 删除作息设置
     *
     * @param id 作息设置主键
     * @return 结果
     */
     int deleteSysWorkTimeSetById(Long id);

    /**
     * 批量删除作息设置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysWorkTimeSetByIds(Long[] ids);
}
